﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UnityEngine;
using RimWorld;
using Verse;

namespace PlumbusIncidents {

	class IncidentWorker_FleebPasses : IncidentWorker {

		// Token: 0x06003EB0 RID: 16048 RVA: 0x0014B170 File Offset: 0x00149370
		protected override bool CanFireNowSub(IncidentParms parms) {
			Map map = (Map)parms.target;
			IntVec3 intVec;
			return !map.gameConditionManager.ConditionIsActive(GameConditionDefOf.ToxicFallout) && map.mapTemperature.SeasonAndOutdoorTemperatureAcceptableFor(ThingDefOfPlumbusIncidents.Fleeb) && this.TryFindEntryCell(map, out intVec);
		}

		// Token: 0x06003EB1 RID: 16049 RVA: 0x0014B1BC File Offset: 0x001493BC
		protected override bool TryExecuteWorker(IncidentParms parms) {
			Map map = (Map)parms.target;
			IntVec3 intVec;
			if (!this.TryFindEntryCell(map, out intVec)) {
				return false;
			}
			PawnKindDef fleeb = PawnKindDefOfPlumbusIncidents.Fleeb;
			int num = GenMath.RoundRandom(StorytellerUtility.DefaultThreatPointsNow(map) / fleeb.combatPower);
			int max = Rand.RangeInclusive(8, 10);
			int min = Rand.RangeInclusive(3, 6);
			num = Mathf.Clamp(num, min, max);
			int num2 = Rand.RangeInclusive(90000, 150000);
			IntVec3 invalid = IntVec3.Invalid;
			if (!RCellFinder.TryFindRandomCellOutsideColonyNearTheCenterOfTheMap(intVec, map, 10f, out invalid)) {
				invalid = IntVec3.Invalid;
			}
			Pawn pawn = null;
			for (int i = 0; i < num; i++) {
				IntVec3 loc = CellFinder.RandomClosewalkCellNear(intVec, map, 10, null);
				pawn = PawnGenerator.GeneratePawn(fleeb, null);
				GenSpawn.Spawn(pawn, loc, map, Rot4.Random, WipeMode.Vanish, false);
				pawn.mindState.exitMapAfterTick = Find.TickManager.TicksGame + num2;
				if (invalid.IsValid) {
					pawn.mindState.forcedGotoPosition = CellFinder.RandomClosewalkCellNear(invalid, map, 10, null);
				}
			}
			base.SendStandardLetter("LetterLabelFleebPasses".Translate(fleeb.label).CapitalizeFirst(), "LetterFleebPasses".Translate(fleeb.label), LetterDefOf.PositiveEvent, parms, pawn, Array.Empty<NamedArgument>());
			return true;
		}	

		// Token: 0x06003EB2 RID: 16050 RVA: 0x0014B2FC File Offset: 0x001494FC
		private bool TryFindEntryCell(Map map, out IntVec3 cell) {
			return RCellFinder.TryFindRandomPawnEntryCell(out cell, map, CellFinder.EdgeRoadChance_Animal + 0.2f, false, null);
		}
	}
}
